#
# spec file for package python-pylast
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pylast
Version:        1.8.0
Release:        lp150.1.4
Summary:        A python interface to Last.fm
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://github.com/pylast/pylast
Source0:        https://files.pythonhosted.org/packages/source/p/pylast/pylast-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-six
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%python_subpackages

%description
A Python interface to Last.fm and other API-compatible websites such as Libre.fm

Features:
- Simple public interface.
- Access to all the data exposed by the Last.fm webservices.
- Scrobbling support.
- Full object-oriented design.
- Proxy support.
- Internal caching support for some webservices calls (disabled by default).
- No extra dependencies but python itself.
- Support for other API-compatible networks like Libre.fm
- Python3-friendly (Starting from 0.5).

%prep
%setup -q -n pylast-%{version}

%build
%python_build

%install
%python_install
%python_exec %fdupes -s %{buildroot}/%{python_sitelib}

%files %{python_files}
%defattr(-,root,root)
%doc COPYING
%dir %{python_sitelib}/pylast
%{python_sitelib}/pylast/*
%{python_sitelib}/pylast-%{version}-py%{py_ver}.egg-info

%changelog
* Mon May  8 2017 alarrosa@suse.com
- Use %%python_exec to call %%fdupes separately on each python_sitelib
  directory. Otherwise a symlink from the python3 sitelib directory
  was created to the python2 one, breaking the python3 package when
  the python2 package wasn't installed.
* Thu Apr  6 2017 alarrosa@suse.com
- Converted to singlespec
* Fri Mar 24 2017 alarrosa@suse.com
- update to version 1.8.0:
  * Update error message for test_init_with_token
  * Support authentication tokens to construct networks
  * Update README.md
- update to version 1.7.0:
  * Add python 3.5 and 3.6 tests environments
  * Separate Libre.fm test from Last.fm tests
  * Fix Error message to reference Libre.fm or Last.fm
  * Use default SSL context when possible
  * switch from HTTPConnection to HTTPSConnection
  * Add missing dependency in README, update gitignore for JetBrains
  * Update Libre.fm URL
* Mon May 16 2016 arun@gmx.de
- update to version 1.6.0:
  * Split test into passing and failing tests
  * Skip tests if Last.fm API still broken
  * Include tests in release source tarball
  * Update year
  * pep8 fixes for #153
  * Fix build: no such option: --download-cache
  * Skip more tests which fail due to the (still) broken Last.fm API
  * Skip tests which fail due to the (still) broken Last.fm API
  * x.next() -> next(x) for python3 compat
  * Update __init__.py
  * replaced opensearch: as empty str
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Sun Dec 13 2015 arun@gmx.de
- update to version 1.5.1:
  * Fix tox==2.1.1
  * Add YAML rules [CI skip]
  * Fix album.get_tracks()
  * Fix for #146: only get the top-level <mbid>
- changes from version 1.5.0:
  * Check installation sooner [CI skip]
* Sun Sep 27 2015 arun@gmx.de
- update to version 1.4.2
  * (no changelog available)
- changes from version 1.4.0:
  * Fix get_recent_tracks (and more)
- update to version 1.3.0:
  * Let Tox use these env vars
  * get_tagged_tracks: Use cacheable param
  * flake8
  * pep8 compliance
  * Add test case for Track.get_correction()
  * Add test case for Artist.get_correction()
  * Add suppport for track.getCorrection
  * Add suppport for artist.getCorrection
  * Fixed broken comment
  * User.GetPersonalTags bug fix
  * Added User.GetPersonalTags test cases
  * Fixed broken comment
  * Cleanup of User.GetPersonalTags stuff
  * Support for User.GetPersonalTags
  * Remove useless Scrutinizer badge
  * Replace broken pypip.in badges with shields.io
- changes from version 1.2.1:
  * Remember to release on master
  * Update release checklist
* Sun Aug 16 2015 zaitor@opensuse.org
- Add missing python3-six Requires.
* Sat May  9 2015 arun@gmx.de
- update to version 1.2.1 and 1.2.0:
  * Remove unused import
  * Remove artist.getImages and depracation note
  * Remove commented function
  * Retry failures up to four times, require at least one pass
  * Sometimes Last.fm returns an error for dates[1]: No chart available
  for this user/date-range combination
  * Add EditorConfig
  * Don't compare with limit if limit is None. Fixes #124.
  * Failing test for #124
  * 2015
  * Add licence
  * Don't redefine built-in
  * Remove unused argument
  * Badges: master -> develop, hugovk -> pylast
  * Run fast lint job first
  * Remove unused import
  * pep8 fixes
  * Rerun flaky interation tests
  * Release checklist
* Sun Jan 25 2015 arun@gmx.de
- specfile:
  * update copyright year
  * removed modname variable
  * updated source to point to pypi
  * require setuptools
  * no more README in tar-ball, removed it from %%files section
  * update %%files section
- update to version 1.1.0:
  * Fix pytest.py link
  * Update testing instructions [CI skip]
  * Remove unused .build file
  * fix grep filter for clonedigger.
  * remove dir-locals. make clonedigger always exit 0
  * fix base object hasing. Closes  #120 .
  * Version bump, fix setup.py, which was previously broken because excludes was not a tuple, so each character wa
  * Fix UnicodeDecodeError from #114. Replace definitions of _unicode and _string. Add six as a dependeny. Fix clo
  * Skip if PYLAST_USERNAME etc. env vars missing
  * Revert "Add failing test for #114" (This revert should be reverted later as the test from this commit should b
  * Remove duplicate line, Make test_pylast.py runnable as main again.
  * add credentials for IvanMalison/pylast.
  * Add failing test for #114
  * add posargs to tox tests.
  * Get rid of --doctest-modules in py.test command.
  * Consolidate travis environments. separate matrix and global environment variables.
  * Add tox to travis installation.
  * tox/travis stuff. making testing more uniform.
  * Don't encode strings as 'utf-8' twice in _get_cache_key. Closes #109.
  * Make pylast a package. Move tests into a directory. Start using pytest and tox. Use setuptools instead of dist
  * Remove unused import
  * Don't use .build file for minor version because we define the full version in pylast.py as well
  * Fix word in SessionKeyGenerator comment.
  * Fix params
  * Remove asserts which can fail
  * Landscape.io fixes
  * Add pypy3; track coverage in Scrutinizer
  * Use Docker
  * Update pylast.py
  * Make test more robust
  * Badges! [CI skip]
  * Add from/to parameters to get_recent_tracks()
  * Fix chart tests that failed due to date ranges (take 2)
  * Fix chart tests that failed due to date ranges
  * Last.fm returns no results for artist.getsimilar with limit=1, but limit=2 returns 2
  * Fix comparison with None for artist, album and event, with test. For #97.
  * Add artist.get_band_members() with tests
  * Add PyPI version badge
  * Add badge for number of PyPI downloads
  * syntax highlighting in readme
  * Fix opus comparison with None
  * Update install instructions now 1.0.0 is on PyPI
* Mon Aug  4 2014 p.drouand@gmail.com
- Remove conflict with python-pylast; it doesn't exist
* Mon Aug  4 2014 malcolmlewis@opensuse.org
- Initial build.
